
/*globals define*/

define([
    'testsuite/qunit',
    'jquery',
    'ep/fn/progressbar',

    '$ready!'
], function (QUnit, $, ep) {
    ep('head').append('<link rel="stylesheet" type="text/css" href="../ep/fn/progressbar.css">');

    QUnit.module("ep/fn/progressbar");

    QUnit.asyncTest("ep/fn/progressbar - plugin", function () {
        QUnit.strictEqual(
            $.isFunction(ep.fn.progressbar),
            true,
            '$.isFunction(progressbar):'
        );

        QUnit.start();
    });

    QUnit.asyncTest("ep/fn/progressbar - functionality", function () {
        // start progressbar
        ep.fn.progressbar();

        QUnit.equal(
            $('.ep-progressbar').length,
            1,
            "Progressbar is present in DOM."
        );

        QUnit.ok(
            /width:[\s]{0,1}100%;/.test($('.ep-progressbar-percent').attr('style')),
            "Progressbar's length is 100 percent on start."
        );
        QUnit.ok(
            !$('.ep-progressbar').hasClass('ep-progressbar-hide'),
            "Progressbar is visible on start."
        );

        window.setTimeout(function() {
            QUnit.ok(
                /width:[\s]{0,1}0%;/.test($('.ep-progressbar-percent').attr('style')),
                "Progressbar's length is 0 percent after finishing."
            );
            QUnit.ok(
                $('.ep-progressbar').hasClass('ep-progressbar-hide'),
                "Progressbar is invisible after finishing."
            );

            // restart progressbar with argument
            ep.fn.progressbar('start');

            QUnit.ok(
                /width:[\s]{0,1}100%;/.test($('.ep-progressbar-percent').attr('style')),
                "Progressbar's length is 100 percent after restart."
            );
            QUnit.ok(
                !$('.ep-progressbar').hasClass('ep-progressbar-hide'),
                "Progressbar is visible again after restart."
            );

            window.setTimeout(function() {
                QUnit.ok(
                    /width:[\s]{0,1}0%;/.test($('.ep-progressbar-percent').attr('style')),
                    "Progressbar's length is 0 percent after finishing."
                );
                QUnit.ok(
                    $('.ep-progressbar').hasClass('ep-progressbar-hide'),
                    "Progressbar is invisible after finishing."
                );

                // destroy progressbar plugin
                ep.fn.progressbar('destroy');

                QUnit.equal(
                    $('.ep-progressbar').length,
                    0,
                    "Progressbar was removed from DOM."
                );

                QUnit.start();
            }, 505);
        }, 505);
    });
});